<?php

namespace Drupal\sitemap_block_contents\Plugin\Block;

use Drupal\Core\Block\BlockBase;

use Drupal\Core\Block\BlockPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

use Drupal\Core\Form\FormStateInterface;

/**
 * Provides the Sitemap in a block.
 *
 * @Block(
 *   id = "sitemap_contents",
 *   label = @Translation("Sitemap Contents"),
 *   admin_label = @Translation("Sitemap Contents")
 * )
 */
class SitemapContentsBlock extends BlockBase implements BlockPluginInterface, ContainerFactoryPluginInterface {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructor class __construct.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entityTypeManager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * Create container create.
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#theme' => 'sitemap_block_contents',
    ];
  }

  /**
   * BlockForm.
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();

    $form['sitemap_contents'] = [
      '#type' => 'details',
      '#title' => $this->t('Contents Type'),
      '#open' => TRUE,
    ];

    $types = $this->entityTypeManager
      ->getStorage('node_type')
      ->loadMultiple();

    foreach ($types as $key => $value) {

      $form['sitemap_contents']['content_type'][$key] = [
        '#type' => 'details',
        '#title' => $key,
        '#open' => FALSE,
      ];

      $form['sitemap_contents']['content_type'][$key]['value'] = [
        '#type' => 'checkbox',
        '#title' => $key,
        '#default_value' => isset($config['sitemap_contents']['content_type'][$key]['value']) ? $config['sitemap_contents']['content_type'][$key]['value'] : '',
      ];

      $form['sitemap_contents']['content_type'][$key]['toggle'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Title'),
        '#default_value' => isset($config['sitemap_contents']['content_type'][$key]['toggle']) ? $config['sitemap_contents']['content_type'][$key]['toggle'] : '',
      ];
    }

    return $form;
  }

  /**
   * BlockSubmit.
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $values = $form_state->getValues();
    $this->configuration['sitemap_contents']['content_type'] = $values['sitemap_contents']['content_type'];
  }

}
